lilypondfiletools.LayoutBlock
=============================

.. inheritance-diagram:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.LayoutBlock
   :private-bases:

.. autoclass:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.LayoutBlock

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.LayoutBlock.context_blocks

.. autoattribute:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.LayoutBlock.contexts

.. autoattribute:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.LayoutBlock.lilypond_format

    Inherited from :py:class:`lilypondfiletools.AttributedBlock <abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.AttributedBlock>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.LayoutBlock.is_formatted_when_empty

    Inherited from :py:class:`lilypondfiletools.AttributedBlock <abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.AttributedBlock>`

Special Methods
---------------

.. automethod:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.LayoutBlock.__repr__

    Inherited from :py:class:`lilypondfiletools.AttributedBlock <abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.AttributedBlock>`
